@@ -27,7 +27,7 @@ class QPlugin < Plugin
   end
 
   def set(m, params)
-    @registry['quakenet.user'] = params[:user]
+    @registry['quakenet.user'] = params[:nick]
     @registry['quakenet.auth'] = params[:passwd]
     m.okay
   end
@@ -48,4 +48,4 @@ class QPlugin < Plugin
 end
 plugin = QPlugin.new
 plugin.map 'qauth set :nick :passwd', :action => "set"
-plugin.map 'quath identify', :action => "identify"
+plugin.map 'qauth identify', :action => "identify"
