@@ -3,8 +3,8 @@ class RotPlugin < Plugin
     "rot13 <string> => encode <string> to rot13 or back"
   end
   def rot13(m, params)
-    m.reply params[:string].tr("A-Za-z", "N-ZA-Mn-za-m");
+    m.reply params[:string].join(" ").tr("A-Za-z", "N-ZA-Mn-za-m");
   end
 end
 plugin = RotPlugin.new
-plugin.map 'rot13 :string'
+plugin.map 'rot13 *string'
